@@ -10,6 +10,8 @@ class Arithmetic(Enum):
     sub = "-"
     mul = "*"
     div = "/"
+    lshift = "<<"
+    rshift = ">>"
 
 
 class Comparator(Enum):
@@ -32,6 +34,7 @@ class Matching(Comparator):
     ilike = " ILIKE "
     rlike = " RLIKE "
     regex = " REGEX "
+    regexp = " REGEXP "
     bin_regex = " REGEX BINARY "
     as_of = " AS OF "
     glob = " GLOB "
