@@ -384,6 +384,18 @@ class Query:
         """
         return CreateQueryBuilder().create_table(table)
 
+    @classmethod
+    def drop_database(cls, database: Union[Database, Table]) -> "DropQueryBuilder":
+        """
+        Query builder entry point. Initializes query building and sets the table name to be dropped. When using this
+        function, the query becomes a DROP statement.
+
+        :param database: An instance of a Database object or a string database name.
+
+        :return: DropQueryBuilder
+        """
+        return DropQueryBuilder().drop_database(database)
+
     @classmethod
     def drop_table(cls, table: Union[str, Table]) -> "DropQueryBuilder":
         """
@@ -396,6 +408,30 @@ class Query:
         """
         return DropQueryBuilder().drop_table(table)
 
+    @classmethod
+    def drop_user(cls, user: str) -> "DropQueryBuilder":
+        """
+        Query builder entry point. Initializes query building and sets the table name to be dropped. When using this
+        function, the query becomes a DROP statement.
+
+        :param user: String user name.
+
+        :return: DropQueryBuilder
+        """
+        return DropQueryBuilder().drop_user(user)
+
+    @classmethod
+    def drop_view(cls, view: str) -> "DropQueryBuilder":
+        """
+        Query builder entry point. Initializes query building and sets the table name to be dropped. When using this
+        function, the query becomes a DROP statement.
+
+        :param view: String view name.
+
+        :return: DropQueryBuilder
+        """
+        return DropQueryBuilder().drop_view(view)
+
     @classmethod
     def into(cls, table: Union[Table, str], **kwargs: Any) -> "QueryBuilder":
         """
@@ -678,6 +714,7 @@ class QueryBuilder(Selectable, Term):
         self._orderbys = []
         self._joins = []
         self._unions = []
+        self._using = []
 
         self._limit = None
         self._offset = None
@@ -836,24 +873,12 @@ class QueryBuilder(Selectable, Term):
 
     @builder
     def insert(self, *terms: Any) -> "QueryBuilder":
-        if self._insert_table is None:
-            raise AttributeError("'Query' object has no attribute '%s'" % "insert")
-
-        if not terms:
-            return
-        else:
-            self._validate_terms_and_append(*terms)
+        self._apply_terms(*terms)
         self._replace = False
 
     @builder
     def replace(self, *terms: Any) -> "QueryBuilder":
-        if self._insert_table is None:
-            raise AttributeError("'Query' object has no attribute '%s'" % "insert")
-
-        if not terms:
-            return
-        else:
-            self._validate_terms_and_append(*terms)
+        self._apply_terms(*terms)
         self._replace = True
 
     @builder
@@ -1139,11 +1164,17 @@ class QueryBuilder(Selectable, Term):
         subquery.alias = "sq%d" % self._subquery_count
         self._subquery_count += 1
 
-    def _validate_terms_and_append(self, *terms: Any) -> None:
+    def _apply_terms(self, *terms: Any) -> None:
         """
         Handy function for INSERT and REPLACE statements in order to check if
         terms are introduced and how append them to `self._values`
         """
+        if self._insert_table is None:
+            raise AttributeError("'Query' object has no attribute '%s'" % "insert")
+
+        if not terms:
+            return
+
         if not isinstance(terms[0], (list, tuple, set)):
             terms = [terms]
 
@@ -1264,6 +1295,9 @@ class QueryBuilder(Selectable, Term):
         if self._from:
             querystring += self._from_sql(**kwargs)
 
+        if self._using:
+            querystring += self._using_sql(**kwargs)
+
         if self._force_indexes:
             querystring += self._force_index_sql(**kwargs)
 
@@ -1388,6 +1422,11 @@ class QueryBuilder(Selectable, Term):
             selectable=",".join(clause.get_sql(subquery=True, with_alias=True, **kwargs) for clause in self._from)
         )
 
+    def _using_sql(self, with_namespace: bool = False, **kwargs: Any) -> str:
+        return " USING {selectable}".format(
+            selectable=",".join(clause.get_sql(subquery=True, with_alias=True, **kwargs) for clause in self._using)
+        )
+
     def _force_index_sql(self, **kwargs: Any) -> str:
         return " FORCE INDEX ({indexes})".format(
             indexes=",".join(index.get_sql(**kwargs) for index in self._force_indexes),
@@ -1527,10 +1566,7 @@ class Joiner:
 
     def using(self, *fields: Any) -> QueryBuilder:
         if not fields:
-            raise JoinException(
-                "Parameter 'fields' is required when joining with "
-                "a using clause but was not supplied.".format(type=self.type_label)
-            )
+            raise JoinException("Parameter 'fields' is required when joining with a using clause but was not supplied.")
 
         self.query.do_join(JoinUsing(self.item, self.how, [Field(field) for field in fields]))
         return self.query
@@ -1938,7 +1974,8 @@ class DropQueryBuilder:
     QUERY_CLS = Query
 
     def __init__(self, dialect: Optional[Dialects] = None) -> None:
-        self._drop_table = None
+        self._drop_target_kind = None
+        self._drop_target: Union[Database, Table, str] = ""
         self._if_exists = None
         self.dialect = dialect
 
@@ -1947,35 +1984,49 @@ class DropQueryBuilder:
         kwargs.setdefault("secondary_quote_char", self.SECONDARY_QUOTE_CHAR)
         kwargs.setdefault("dialect", self.dialect)
 
-    def get_sql(self, **kwargs: Any) -> str:
-        self._set_kwargs_defaults(kwargs)
-
-        if not self._drop_table:
-            return ""
-
-        querystring = self._drop_table_sql(**kwargs)
-
-        return querystring
+    @builder
+    def drop_database(self, database: Union[Database, str]) -> "DropQueryBuilder":
+        target = database if isinstance(database, Database) else Database(database)
+        self._set_target('DATABASE', target)
 
     @builder
     def drop_table(self, table: Union[Table, str]) -> "DropQueryBuilder":
-        if self._drop_table:
-            raise AttributeError("'Query' object already has attribute drop_table")
+        target = table if isinstance(table, Table) else Table(table)
+        self._set_target('TABLE', target)
 
-        self._drop_table = table if isinstance(table, Table) else Table(table)
+    @builder
+    def drop_user(self, user: str) -> "DropQueryBuilder":
+        self._set_target('USER', user)
+
+    @builder
+    def drop_view(self, view: str) -> "DropQueryBuilder":
+        self._set_target('VIEW', view)
 
     @builder
     def if_exists(self) -> "DropQueryBuilder":
         self._if_exists = True
 
-    def _drop_table_sql(self, **kwargs: Any) -> str:
-        if_exists = ''
-        if self._if_exists:
-            if_exists = 'IF EXISTS '
+    def _set_target(self, kind: str, target: Union[Database, Table, str]) -> None:
+        if self._drop_target:
+            raise AttributeError("'DropQuery' object already has attribute drop_target")
+        self._drop_target_kind = kind
+        self._drop_target = target
 
-        return "DROP TABLE {if_exists}{table}".format(
-            if_exists=if_exists,
-            table=self._drop_table.get_sql(**kwargs),
+    def get_sql(self, **kwargs: Any) -> str:
+        self._set_kwargs_defaults(kwargs)
+
+        if_exists = 'IF EXISTS ' if self._if_exists else ''
+        target_name: str = ""
+
+        if isinstance(self._drop_target, Database):
+            target_name = self._drop_target.get_sql(**kwargs)
+        elif isinstance(self._drop_target, Table):
+            target_name = self._drop_target.get_sql(**kwargs)
+        else:
+            target_name = format_quotes(self._drop_target, self.QUOTE_CHAR)
+
+        return "DROP {kind} {if_exists}{name}".format(
+            kind=self._drop_target_kind, if_exists=if_exists, name=target_name
         )
 
     def __str__(self) -> str:
